@@ -1,4 +1,3 @@
-#define PING() fprintf (stderr, "%d:%s:%d\n",getpid(),__FILE__,__LINE__),fflush(stderr)
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
  *  bonobo-activation: A library for accessing bonobo-activation-server.
@@ -313,20 +312,20 @@ bonobo_activation_object_directory_get (const char *username,
         Bonobo_ActivationContext new_ac;
         Bonobo_ObjectDirectoryList *od_list;
         static Bonobo_ActivationContext ac = CORBA_OBJECT_NIL;
-PING();
+
         new_ac = bonobo_activation_activation_context_get ();
         if (ac == new_ac)
                 return object_directory;
         ac = new_ac;
-PING();
+
         CORBA_exception_init (&ev);
-PING();
+
         od_list = Bonobo_ActivationContext__get_directories (ac, &ev);
-PING();        if (ev._major != CORBA_NO_EXCEPTION) {
+        if (ev._major != CORBA_NO_EXCEPTION) {
                 CORBA_exception_free (&ev);
                 return CORBA_OBJECT_NIL;
         }
-PING();
+
         if (od_list->_length != 1) {
                 g_warning ("Extremely strange, strange object directories (%d)"
                            "registered with the activation context", od_list->_length);
@@ -334,12 +333,12 @@ PING();
                 CORBA_exception_free (&ev);
                 return CORBA_OBJECT_NIL;
         }
-PING();
+
         object_directory = CORBA_Object_duplicate (od_list->_buffer[0], &ev);
         
         CORBA_free (od_list);
         CORBA_exception_free (&ev);
-PING();
+
         return object_directory;
 }
 
