@@ -13,7 +13,7 @@
 #define BONOBO_EXPLICIT_TRANSLATION_DOMAIN GETTEXT_PACKAGE
 #include <bonobo/bonobo-i18n.h>
 #include <bonobo/bonobo-object.h>
-#include <bonobo/bonobo-shutdown.h>
+#include <bonobo/bonobo-private.h>
 #include <bonobo/bonobo-exception.h>
 
 typedef enum {
